@@ -4,5 +4,5 @@ SYM_ENCRYPT_SQL_WITH_NULLIF = "pgp_sym_encrypt(nullif(%s, NULL)::text, '{}')"
 ASYM_ENCRYPT_SQL = "pgp_pub_encrypt(%s, dearmor('{}'))"
 SYM_ENCRYPT_SQL = "pgp_sym_encrypt(%s, '{}')"
 
-ASYM_DECRYPT_SQL = "pgp_pub_decrypt(%s, dearmor('{}'))::%s"
-SYM_DECRYPT_SQL = "pgp_sym_decrypt(%s, '{}')::%s"
+ASYM_DECRYPT_SQL = "pgp_pub_decrypt(%s::bytea, dearmor('{}'))::%s"
+SYM_DECRYPT_SQL = "pgp_sym_decrypt(%s::bytea, '{}')::%s"
